#
# spec file for package libsearpc
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
Name:           libsearpc
Version:        3.3.0.20230527
Release:        1.3
Summary:        Simple C language RPC framework based on GObject system
License:        Apache-2.0
Group:          System/Libraries
URL:            https://github.com/haiwen/libsearpc/
Source0:        %{name}-%{version}.tar.gz
Patch0:         01-fix-includes.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gmodule-export-2.0)
BuildRequires:  pkgconfig(gmodule-no-export-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(python3)
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  jansson-devel
%else
BuildRequires:  pkgconfig(jansson)
%endif

%description
Searpc is a simple C language RPC framework based on GObject system. Searpc handles the serialization/deserialization part of RPC, the transport part is left to users.

The serialization/deserialization uses JSON format via json-glib library. A serialized json object is returned from server to client after executing the RPC function. Each RPC function defined in the server side should take an extra GError argument to report error.

%package  -n   %{name}%{sover}
Summary:        Library to handle the serialization/deserialization part of RPC
Group:          System/Libraries

%description  -n   %{name}%{sover}
Searpc is a simple C language RPC framework based on GObject system. Searpc handles the serialization/deserialization part of RPC, the transport part is left to users.

The serialization/deserialization uses JSON format via json-glib library. A serialized json object is returned from server to client after executing the RPC function. Each RPC function defined in the server side should take an extra GError argument to report error.

%package        devel
Summary:        Development files for %{name}
Group:          System/Libraries
Requires:       %{name}%{sover} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package        -n python3-pysearpc
Summary:        Python files for %{name}
Group:          System/Libraries
Requires:       %{name}%{sover} = %{version}

%description    -n python3-pysearpc
The python-pysearpc package contains python files to make use of %{name}.

%prep
%autosetup -p1

%build
./autogen.sh
%configure --disable-static --with-python3
%make_build
sed -i -e 's#^prefix.*#prefix=/usr#g' libsearpc.pc
sed -i -e 's/#!\/usr\/bin\/env python/#!\/usr\/bin\/python3/' lib/searpc-codegen.py

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -type f -name "*.opt-1.pyc" -delete -print

%post   -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license LICENSE.txt
%doc README.markdown AUTHORS
%{_libdir}/%{name}.so.%{sover}
%{_libdir}/%{name}.so.%{sover}.*

%files devel
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/libsearpc.pc
%{_bindir}/searpc-codegen.py

%files -n python3-pysearpc
%dir %{python3_sitearch}/pysearpc
%{python3_sitearch}/pysearpc/*.py
%dir %{python3_sitearch}/pysearpc/__pycache__/
%{python3_sitearch}/pysearpc/__pycache__/*.pyc

%changelog
* Mon Jul  3 2023 info@paolostivanin.com
- Update to version 3.3.0.20230527:
  * Close socket when failed to connect name pipe (#65)
  * Support compile universal (#64)
* Wed Apr 12 2023 info@paolostivanin.com
- Update to version 3.3.0.20230224:
  * Waiting with WaitNamedPipe() if a named pipe is busy (#62)
  * Filter rpc slow log include password (#61)
  * Add support c++ compile (#60)
  * Change slow log format (#58)
  * Configure x64-debug build (#56)
  * add --with-python3 option (#55)
  * only use python3 in linux (#54)
  * remove python3 future
  * configure with python3 (#53)
  * Fixed python-searpc installation place (#52)
* Mon Nov  7 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.3.0.20220902:
  * Filter rpc slow log include password.
  * Add C++ support.
* Mon May  9 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.0.20220425, no changelog
- Rebase 01-fix-includes.patch
- Drop libsearpc-fix-compilation-glib2_68.patch
* Fri Dec 10 2021 Paolo Stivanin <info@paolostivanin.com>
- New release, no changelog
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Add libsearpc-fix-compilation-glib2_68.patch
* Thu Jun 25 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.0.20200618 (no changelog)
* Fri Apr 10 2020 Paolo Stivanin <info@paolostivanin.com>
- Use _service and _servicedata since upstream has the bad habit
  of issuing a new release by overwriting the old one
* Tue Mar 10 2020 Paolo Stivanin <info@paolostivanin.com>
- change package name to libsearpc and improve spec file
* Mon Dec  9 2019 Paolo Stivanin <info@paolostivanin.com>
- Use latest master which brings a fix for a memory leak
* Fri Nov 15 2019 Paolo Stivanin <info@paolostivanin.com>
- run spec-cleaner
* Tue Nov 12 2019 Paolo Stivanin <info@paolostivanin.com>
- Update to 3.2.0
* Fri Jan 18 2019 Pierre Bonamy <flyos@mailoo.org>
- Update to latest version of 3.1
- As upstream did not increment version, added date in version
* Wed Mar 28 2018 christoph@stop.pe
- Fixed build errors on CentOS 7
* Sat Feb 25 2017 christoph@stop.pe
- Updated source link to official github.com release page
* Sat Sep 24 2016 christoph@stop.pe
- Moved code generation script to devel package
* Sat Sep 24 2016 christoph@stop.pe
- Fix and added libsearpc.pc to devel package
* Sat Sep 24 2016 christoph@stop.pe
- Initial packaging
